﻿################################################################################
## Initialization
################################################################################

init offset = -1


################################################################################
## Styles
################################################################################

style default:
    properties gui.text_properties()
    language gui.language

style input:
    properties gui.text_properties("input", accent=True)
    adjust_spacing False

style hyperlink_text:
    properties gui.text_properties("hyperlink", accent=True)
    hover_underline True

style gui_text:
    properties gui.text_properties("interface")


style button:
    properties gui.button_properties("button")

style button_text is gui_text:
    properties gui.text_properties("button")
    yalign 0.5


style label_text is gui_text:
    properties gui.text_properties("label", accent=True)

style prompt_text is gui_text:
    properties gui.text_properties("prompt")


style bar:
    ysize gui.bar_size
    left_bar Frame("gui/bar/left.png", gui.bar_borders, tile=gui.bar_tile)
    right_bar Frame("gui/bar/right.png", gui.bar_borders, tile=gui.bar_tile)

style vbar:
    xsize gui.bar_size
    top_bar Frame("gui/bar/top.png", gui.vbar_borders, tile=gui.bar_tile)
    bottom_bar Frame("gui/bar/bottom.png", gui.vbar_borders, tile=gui.bar_tile)

style scrollbar:
    ysize gui.scrollbar_size
    base_bar Frame("gui/scrollbar/horizontal_[prefix_]bar.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/scrollbar/horizontal_[prefix_]thumb.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)

style vscrollbar:
    xsize gui.scrollbar_size
    base_bar Frame("gui/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/scrollbar/vertical_[prefix_]thumb.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)

style slider:
    ysize gui.slider_size
    base_bar Frame("gui/slider/horizontal_[prefix_]bar.png", gui.slider_borders, tile=gui.slider_tile)
    thumb "gui/slider/horizontal_[prefix_]thumb.png"

style vslider:
    xsize gui.slider_size
    base_bar Frame("gui/slider/vertical_[prefix_]bar.png", gui.vslider_borders, tile=gui.slider_tile)
    thumb "gui/slider/vertical_[prefix_]thumb.png"


style frame:
    padding gui.frame_borders.padding
    background Frame("gui/frame.png", gui.frame_borders, tile=gui.frame_tile)



################################################################################
## In-game screens
################################################################################


## Say screen ##################################################################
##
## The say screen is used to display dialogue to the player. It takes two
## parameters, who and what, which are the name of the speaking character and
## the text to be displayed, respectively. (The who parameter can be None if no
## name is given.)
##
## This screen must create a text displayable with id "what", as Ren'Py uses
## this to manage text display. It can also create displayables with id "who"
## and id "window" to apply style properties.
##
## https://www.renpy.org/doc/html/screen_special.html#say

screen say(who, what):
    style_prefix "say"

    window:
        id "window"

        if who is not None:

            window:
                id "namebox"
                style "namebox"
                text who id "who"

        text what id "what"


    ## If there's a side image, display it above the text. Do not display on the
    ## phone variant - there's no room.
    if not renpy.variant("small"):
        add SideImage() xalign 0.0 yalign 1.0


## Make the namebox available for styling through the Character object.
init python:
    config.character_id_prefixes.append('namebox')

style window is default
style say_label is default
style say_dialogue is default
style say_thought is say_dialogue

style namebox is default
style namebox_label is say_label


style window:
    xalign 0.5
    xfill True
    yalign gui.textbox_yalign
    ysize gui.textbox_height

    background Image("gui/textbox.png", xalign=0.5, yalign=1.0)

style namebox:
    xpos gui.name_xpos
    xanchor gui.name_xalign
    xsize gui.namebox_width
    ypos gui.name_ypos
    ysize gui.namebox_height

    background Frame("gui/namebox.png", gui.namebox_borders, tile=gui.namebox_tile, xalign=gui.name_xalign)
    padding gui.namebox_borders.padding

style say_label:
    properties gui.text_properties("name", accent=True)
    xalign gui.name_xalign
    yalign 0.5

style say_dialogue:
    properties gui.text_properties("dialogue")

    xpos gui.dialogue_xpos
    xsize gui.dialogue_width
    ypos gui.dialogue_ypos


## Input screen ################################################################
##
## This screen is used to display renpy.input. The prompt parameter is used to
## pass a text prompt in.
##
## This screen must create an input displayable with id "input" to accept the
## various input parameters.
##
## https://www.renpy.org/doc/html/screen_special.html#input

screen input(prompt):
    style_prefix "input"

    window:

        vbox:
            xalign gui.dialogue_text_xalign
            xpos gui.dialogue_xpos
            xsize gui.dialogue_width
            ypos gui.dialogue_ypos

            text prompt style "input_prompt"
            input id "input"

style input_prompt is default

style input_prompt:
    xalign gui.dialogue_text_xalign
    properties gui.text_properties("input_prompt")

style input:
    xalign gui.dialogue_text_xalign
    xmaximum gui.dialogue_width


## Choice screen ###############################################################
##
## This screen is used to display the in-game choices presented by the menu
## statement. The one parameter, items, is a list of objects, each with caption
## and action fields.
##
## https://www.renpy.org/doc/html/screen_special.html#choice

screen choice(items):
    style_prefix "choice"

    vbox:
        for i in items:
            textbutton i.caption action i.action


## When this is true, menu captions will be spoken by the narrator. When false,
## menu captions will be displayed as empty buttons.
define config.narrator_menu = True


style choice_vbox is vbox
style choice_button is button
style choice_button_text is button_text

style choice_vbox:
    xalign 0.5
    ypos 705
    yanchor 0.5

    spacing gui.choice_spacing

style choice_button is default:
    properties gui.button_properties("choice_button")

style choice_button_text is default:
    properties gui.button_text_properties("choice_button")


## Quick Menu screen ###########################################################
##
## The quick menu is displayed in-game to provide easy access to the out-of-game
## menus.

screen quick_menu():

    # Ensure this appears on top of other screens.
    zorder 100

    if quick_menu:

        hbox:
            style_prefix "quick"

            xalign 0.5
            yalign 1.0

            textbutton _("Vissza") action Rollback()
            textbutton _("Eddigiek") action ShowMenu('history')
            textbutton _("Átlép") action Skip() alternate Skip(fast=True, confirm=True)
            textbutton _("Auto") action Preference("auto-forward", "toggle")
            textbutton _("mentés") action ShowMenu('save')
            textbutton _("Gyorsmentés") action QuickSave()
            textbutton _("Gyorstöltés") action QuickLoad()
            textbutton _("Prefs") action ShowMenu('preferences')


## This code ensures that the quick_menu screen is displayed in-game, whenever
## the player has not explicitly hidden the interface.
init python:
    config.overlay_screens.append("quick_menu")

default quick_menu = False

style quick_button is default
style quick_button_text is button_text

style quick_button:
    properties gui.button_properties("quick_button")

style quick_button_text:
    properties gui.button_text_properties("quick_button")


################################################################################
## Main and Game Menu Screens
################################################################################

## Navigation screen ###########################################################
##
## This screen is included in the main and game menus, and provides navigation
## to other menus, and to start the game.

screen navigation():

    add "gui/textbox.png" ypos 852

    vbox:
        xalign 0.48
        yalign 0.95
        if not main_menu:
            textbutton _("{u}{size=+10}Főmenü{/size}{/u}") action MainMenu()

    hbox:
        yalign 0.88
        xalign 0.5
        if preferences.language == "spanish":
            spacing 50
        else:
            spacing 100
#         style_prefix "navigation"
#
#         xpos gui.navigation_xpos
#         yalign 0.5
#
#         spacing gui.navigation_spacing
#
#
#
        if main_menu:

            textbutton _("{u}{size=+3}Új játék{/size}{/u}") action Start()
#
        else:

            textbutton _("{u}{size=+3}Eddigiek{/size}{/u}") action ShowMenu("history")

            textbutton _("{u}{size=+3}Mentés{/size}{/u}") action ShowMenu("save")

        textbutton _("{u}{size=+3}Betöltés{/size}{/u}") action ShowMenu("load")

        textbutton _("{u}{size=+3}Beállítások{/size}{/u}") action ShowMenu("preferences")

        textbutton _("{u}{size=+3}Weboldalunk{/size}{/u}") action OpenURL("https://www.incetongames.com/")

        textbutton _("{u}{size=+3}Hangszínészek{/size}{/u}") action ShowMenu("vo_act")

        if _in_replay:

            textbutton _("{u}{size=+10}Vége ismétlése{/size}{/u}") action EndReplay(confirm=True)

        #textbutton _("About") action ShowMenu("about")

        #textbutton _("Support us on Patreon") action OpenURL("https://www.patreon.com/Inceton")

        #textbutton _("Súgó") action ShowMenu("help")

        if renpy.variant("pc"):

            #textbutton _("Help") action ShowMenu("help")

            ## The quit button is banned on iOS and unnecessary on Android.
            textbutton _("{u}{size=+3}Kilépés{/size}{/u}") action Quit(confirm=not main_menu)

    if main_menu:
        hbox:
            yalign 0.97
            xalign 0.5
            spacing 100
            textbutton _("{u}Egyéb Steam játékaink{/u}") action OpenURL("https://store.steampowered.com/search/?term=inceton")

#
#
style navigation_button is gui_button
style navigation_button_text is gui_button_text
#
style navigation_button:
    size_group "navigation"
    properties gui.button_properties("navigation_button")
#
style navigation_button_text:
    properties gui.button_text_properties("navigation_button")

## Main Menu screen ############################################################
##
## Used to display the main menu when Ren'Py starts.
##
## https://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu_ach:
    $ achievement.grant("ACHID1")
    $ achievement.sync()
    $ check_ach()

screen about_ach:
    $ achievement.grant("ACHID45")
    $ achievement.sync()
    $ check_ach()

screen main_menu():

    ## This ensures that any other menu screen is replaced.
    tag menu

    style_prefix "main_menu"


    #add gui.main_menu_background
    add Movie(play="main_menu_bg.webm")
    timer 87.0 action Show("main_menu_ach")

    ## This empty frame darkens the main menu.
    frame:
        pass


    ## The use statement includes another screen inside this one. The actual
    ## contents of the main menu are in the navigation screen.
    use navigation

    if gui.show_name:

        # vbox:
        #     xpos 1908
        #     yalign 0.05
        #     imagebutton auto "buttons/logo_link_%s.png" action OpenURL("https://www.patreon.com/Inceton")

        vbox:
            xpos 1764
            ypos 100
            imagebutton auto "buttons/follow_button_1_yt_%s.png" action OpenURL("https://www.youtube.com/channel/UC_e5oDR_V2zUirwK6OGz5RQ/featured")

        vbox:
            xpos 1836
            ypos 100
            imagebutton auto "buttons/follow_button_2_tt_%s.png" action OpenURL("https://twitter.com/inceton")

        vbox:
            xpos 1908
            ypos 100
            imagebutton auto "buttons/follow_button_3_dc_%s.png" action OpenURL("https://discord.gg/zw7XeZY")

        # vbox:
        #     xpos 1908
        #     ypos 256
        #     imagebutton auto "buttons/follow_button_4_ss_%s.png" action OpenURL("https://subscribestar.adult/inceton-games")

        vbox:
            xalign 0.05
            yalign 0.96

        vbox:
            text "":
                style "main_menu_title"

            text "{b}{color=#f814cc}SEASON 1{/color}\n{color=#f814cc}{size=10}  Steam build 1.1 - EarlyAccess{/size}{/color}{/b}":
                style "main_menu_version"
                yalign 0.98


# style main_menu_frame is empty
# style main_menu_vbox is vbox
# style main_menu_text is gui_text
# style main_menu_title is main_menu_text
# style main_menu_version is main_menu_text

style main_menu_frame:
    xsize 420
    yfill True
    background "gui/overlay/main_menu.png"

style main_menu_vbox:
    xalign 1.0
    xoffset -30
    xmaximum 1200
    yalign 1.0
    yoffset -30

style main_menu_text:
    properties gui.text_properties("main_menu", accent=True)

style main_menu_title:
    properties gui.text_properties("title")

style main_menu_version:
    properties gui.text_properties("version")


## Game Menu screen ############################################################
##
## This lays out the basic common structure of a game menu screen. It's called
## with the screen title, and displays the background, title, and navigation.
##
## The scroll parameter can be None, or one of "viewport" or "vpgrid". When
## this screen is intended to be used with one or more children, which are
## transcluded (placed) inside it.

screen game_menu(title, scroll=None, yinitial=0.0):
    tag menu


    style_prefix "game_menu"

    if main_menu:
        add gui.main_menu_background
    else:
        add gui.game_menu_background

    frame:
        style "game_menu_outer_frame"

        hbox:

            ## Reserve space for the navigation section.
            frame:
                style "game_menu_navigation_frame"

            frame:
                style "game_menu_content_frame"

                if scroll == "viewport":

                    viewport:
                        yinitial yinitial
                        scrollbars "vertical"
                        mousewheel True
                        draggable True
                        pagekeys True

                        side_yfill True

                        vbox:
                            transclude

                elif scroll == "vpgrid":

                    vpgrid:
                        cols 1
                        yinitial yinitial

                        scrollbars "vertical"
                        mousewheel True
                        draggable True
                        pagekeys True

                        side_yfill True

                        transclude

                else:

                    transclude

    use navigation

    textbutton _("Vissza"):
        style "return_button"

        action Return()

    label title

    if main_menu:
        key "game_menu" action ShowMenu("main_menu")


style game_menu_outer_frame is empty
style game_menu_navigation_frame is empty
style game_menu_content_frame is empty
style game_menu_viewport is gui_viewport
style game_menu_side is gui_side
style game_menu_scrollbar is gui_vscrollbar

style game_menu_label is gui_label
style game_menu_label_text is gui_label_text

style return_button is navigation_button
style return_button_text is navigation_button_text

style game_menu_outer_frame:
    bottom_padding 45
    top_padding 180

    background "gui/overlay/game_menu.png"

style game_menu_navigation_frame:
    xsize 420
    yfill True

style game_menu_content_frame:
    left_margin 60
    right_margin 30
    top_margin 15

style game_menu_viewport:
    xsize 1380

style game_menu_vscrollbar:
    unscrollable gui.unscrollable

style game_menu_side:
    spacing 15

style game_menu_label:
    xpos 75
    ysize 180

style game_menu_label_text:
    size gui.title_text_size
    color gui.accent_color
    yalign 0.5

style return_button:
    xpos gui.navigation_xpos
    yalign 1.0
    yoffset -45


## About screen ################################################################
##
## This screen gives credit and copyright information about the game and Ren'Py.
##
## There's nothing special about this screen, and hence it also serves as an
## example of how to make a custom screen.

screen about():

    tag menu

    ## This use statement includes the game_menu screen inside this one. The
    ## vbox child is then included inside the viewport inside the game_menu
    ## screen.
    use game_menu(_("About"), scroll="viewport"):

        style_prefix "about"

    vbox:
        xpos 300
        ypos 200

        label "[config.name!t]"
        text _("Version [config.version!t]\n")

        ## gui.about is usually set in options.rpy.
        if gui.about:
            text "[gui.about!t]\n"

        side ("c r"):
            area (1,0,1450,470)
            viewport id "about":
                draggable True mousewheel True
                text _("Csak egy átlagos nap_ \nMég egy átlagos nap_"\
                "\nJust another normal day_ \nJust another normal day_ \nJust another normal day_ \nJust another normal day_ \nJust another normal day_"\
                "\nJust another normal day_ \nJust another normal day_ \nJust another normal day_ \nJust another normal day_ \nJust another normal day_"\
                "\nJust another normal day_ \nJust another normal day_ \nJust another normal day_ \nJust another normal day_ \nJust another normal day_"\
                "\nJust another normal day_ \nJust another normal day_ \nJust another normal day_ \nJust another normal day_ \nJust another normal day_"\
                "\nJust another normal day_ \nJust another normal day_ \nJust another normal day_ \nJust another normal day_"\
                "\n{color=#ff0000}//STOP PRYING. GO PLAY THE GAME_{/color}")
            vbar value YScrollValue("about")
    null height 20


## This is redefined in options.rpy to add text to the about screen.
define gui.about = ""


style about_label is gui_label
style about_label_text is gui_label_text
style about_text is gui_text

style about_label_text:
    size gui.label_text_size

## Mute a person screen ########################################################
screen mute_person():
    tag menu

    use game_menu(_("Mute Person"), scroll="viewport"):

        style_prefix "about"

        vbox:
            spacing 200
            hbox:
                spacing 300
                vbox:
                    xminimum 200
                    if not persistent.muted_meg:
                        image "bg/char_voice_on.png" xoffset 75
                        textbutton "Némít Megan" action [ToggleVariable("persistent.muted_meg"), ToggleVoiceMute("meg")]
                    else:
                        image "bg/char_voice_off.png" xoffset 75
                        textbutton "Némít Megan" action [ToggleVariable("persistent.muted_meg"), ToggleVoiceMute("meg")]

                vbox:
                    xminimum 200
                    if not persistent.muted_jess:
                        image "bg/char_voice_on.png" xoffset 75
                        textbutton "Némít Jessica" action [ToggleVariable("persistent.muted_jess"), ToggleVoiceMute("jess")]
                    else:
                        image "bg/char_voice_off.png" xoffset 75
                        textbutton "Némít Jessica" action [ToggleVariable("persistent.muted_jess"), ToggleVoiceMute("jess")]

                vbox:
                    xminimum 200
                    if not persistent.muted_eliz:
                        image "bg/char_voice_on.png" xoffset 75
                        textbutton "Némít Elizabeth" action [ToggleVariable("persistent.muted_eliz"), ToggleVoiceMute("eliz")]
                    else:
                        image "bg/char_voice_off.png" xoffset 75
                        textbutton "Némít Elizabeth" action [ToggleVariable("persistent.muted_eliz"), ToggleVoiceMute("eliz")]

            hbox:
                spacing 300
                vbox:
                    xminimum 200
                    if not persistent.muted_zoe:
                        image "bg/char_voice_on.png" xoffset 75
                        textbutton "Némít Zoe" action [ToggleVariable("persistent.muted_zoe"), ToggleVoiceMute("zoe")]
                    else:
                        image "bg/char_voice_off.png" xoffset 75
                        textbutton "Némít Zoe" action [ToggleVariable("persistent.muted_zoe"), ToggleVoiceMute("zoe")]

                vbox:
                    xminimum 200
                    if not persistent.muted_ellie:
                        image "bg/char_voice_on.png" xoffset 75
                        textbutton "Némít Ellie" action [ToggleVariable("persistent.muted_ellie"), ToggleVoiceMute("ellie")]
                    else:
                        image "bg/char_voice_off.png" xoffset 75
                        textbutton "Némít Ellie" action [ToggleVariable("persistent.muted_ellie"), ToggleVoiceMute("ellie")]

                vbox:
                    xminimum 200
                    if not persistent.muted_nic:
                        image "bg/char_voice_on.png" xoffset 75
                        textbutton "Némít Nicole" action [ToggleVariable("persistent.muted_nic"), ToggleVoiceMute("nic")]
                    else:
                        image "bg/char_voice_off.png" xoffset 75
                        textbutton "Némít Nicole" action [ToggleVariable("persistent.muted_nic"), ToggleVoiceMute("nic")]

            hbox:
                spacing 300
                vbox:
                    xminimum 200
                    if not persistent.muted_soph:
                        image "bg/char_voice_on.png" xoffset 75
                        textbutton "Némít Sophie" action [ToggleVariable("persistent.muted_soph"), ToggleVoiceMute("soph")]
                    else:
                        image "bg/char_voice_off.png" xoffset 75
                        textbutton "Némít Sophie" action [ToggleVariable("persistent.muted_soph"), ToggleVoiceMute("soph")]

                vbox:
                    xminimum 200
                    if not persistent.muted_chloe:
                        image "buttons/char_voice_on.png" xoffset 75
                        textbutton "Némít Chloe" action [ToggleVariable("persistent.muted_chloe"), ToggleVoiceMute("chloe")]
                    else:
                        image "buttons/char_voice_off.png" xoffset 75
                        textbutton "Némít Chloe" action [ToggleVariable("persistent.muted_chloe"), ToggleVoiceMute("chloe")]


## Load and Save screens #######################################################
##
## These screens are responsible for letting the player save the game and load
## it again. Since they share nearly everything in common, both are implemented
## in terms of a third screen, file_slots.
##
## https://www.renpy.org/doc/html/screen_special.html#save https://
## www.renpy.org/doc/html/screen_special.html#load

screen save():

    tag menu

    use file_slots(_("Save"))


screen load():

    tag menu

    use file_slots(_("Load"))


screen file_slots(title):

    default page_name_value = FilePageNameInputValue(pattern=_("Page {}"), auto=_("Automatic saves"), quick=_("Quick saves"))

    use game_menu(title):

        fixed:
            xpos -230
            ypos -180

            ## This ensures the input will get the enter event before any of the
            ## buttons do.
            order_reverse True

            ## The page name, which can be edited by clicking on a button.
            button:
                style "page_label"

                key_events True
                xalign 0.5
                action page_name_value.Toggle()

                input:
                    style "page_label_text"
                    value page_name_value

            ## The grid of file slots.
            grid gui.file_slot_cols gui.file_slot_rows:
                style_prefix "slot"

                xalign 0.5
                yalign 0.5

                spacing gui.slot_spacing

                for i in range(gui.file_slot_cols * gui.file_slot_rows):

                    $ slot = i + 1

                    button:
                        action FileAction(slot)

                        has vbox

                        add FileScreenshot(slot) xalign 0.5

                        text FileTime(slot, format=_("{#file_time}%A, %B %d %Y, %H:%M"), empty=_("üres slot")):
                            style "slot_time_text"

                        text FileSaveName(slot):
                            style "slot_name_text"

                        key "save_delete" action FileDelete(slot)

            ## Buttons to access other pages.
            hbox:
                style_prefix "page"

                xalign 0.5
                yalign 0.95

                spacing gui.page_spacing

                textbutton _("<") action FilePagePrevious()

                if config.has_autosave:
                    textbutton _("{#auto_page}A") action FilePage("auto")

                if config.has_quicksave:
                    textbutton _("{#quick_page}Q") action FilePage("quick")

                ## range(1, 10) gives the numbers from 1 to 9.
                for page in range(1, 10):
                    textbutton "[page]" action FilePage(page)

                textbutton _(">") action FilePageNext()


style page_label is gui_label
style page_label_text is gui_label_text
style page_button is gui_button
style page_button_text is gui_button_text

style slot_button is gui_button
style slot_button_text is gui_button_text
style slot_time_text is slot_button_text
style slot_name_text is slot_button_text

style page_label:
    xpadding 75
    ypadding 5

style page_label_text:
    text_align 0.5
    layout "subtitle"
    hover_color gui.hover_color

style page_button:
    properties gui.button_properties("page_button")

style page_button_text:
    properties gui.button_text_properties("page_button")

style slot_button:
    properties gui.button_properties("slot_button")

style slot_button_text:
    properties gui.button_text_properties("slot_button")


## Preferences screen ##########################################################
##
## The preferences screen allows the player to configure the game to better suit
## themselves.
##
## https://www.renpy.org/doc/html/screen_special.html#preferences

screen preferences():

    tag menu

    use game_menu(_("Preferences"), scroll="viewport"):

        vbox:
            ypos -50

            hbox:
                #box_wrap True

                if renpy.variant("pc"):

                    vbox:
                        ypos 50
                        style_prefix "radio"
                        label _("Display")
                        textbutton _("Ablakos") action Preference("display", "window")
                        textbutton _("Teljes képernyő") action Preference("display", "fullscreen")

                ## Additional vboxes of type "radio_pref" or "check_pref" can be
                ## added here, to add additional creator-defined preferences.

            null height (4 * gui.pref_spacing)

            hbox:
                style_prefix "slider"
                #box_wrap True

                vbox:

                    label _("Text Speed")

                    bar value Preference("text speed")

                    #label _("Auto-Forward Time")

                    #bar value Preference("auto-forward time")

                    # label _("")
                    if not main_menu and not renpy.variant("small"):
                        textbutton _("{size=40}Kapcsolatok módosítása{/size}") action ShowMenu("relation_change")
                    else:
                        label _("")
                    textbutton _("{size=40}About{/size}") action [Show("about_ach"), ShowMenu("about")]
                    textbutton _("{size=40}Súgó{/size}") action ShowMenu("help")
                    if main_menu:
                        textbutton _("{size=40}Nyelvbeállítás{/size}") action ShowMenu("choose_lang_main")
                    hbox:
                        textbutton _("{size=40}Nem látható szöveg kihagyása{/size}") action Preference("skip", "toggle")
                        if preferences.skip_unseen:
                            text "{size=40}{i}{color=#fa6edf}- On{/color}{/i}{/size}" yoffset 6
                        else:
                            text "{size=40}{i}{color=#888888}- Off{/color}{/i}{/size}" yoffset 6


                vbox:

                    if config.has_music:
                        label _("Music Volume")

                        hbox:
                            bar value Preference("music volume")

                    if config.has_sound:

                        label _("Sound Volume")

                        hbox:
                            bar value Preference("sound volume")

                            if config.sample_sound:
                                textbutton _("Test") action Play("sound", config.sample_sound)

                    if config.has_voice:
                        label _("Voice Volume")

                        hbox:
                            bar value Preference("voice volume")

                            if config.sample_voice:
                                textbutton _("Test") action Play("voice", config.sample_voice)

                    if config.has_music or config.has_sound or config.has_voice:
                        null height gui.pref_spacing

                        textbutton _("Mindenki némításal"):
                            action Preference("all mute", "toggle")
                            style "mute_all_button"

                        textbutton _("Speciális némítás"):
                            action ShowMenu("mute_person")


style pref_label is gui_label
style pref_label_text is gui_label_text
style pref_vbox is vbox

style radio_label is pref_label
style radio_label_text is pref_label_text
style radio_button is gui_button
style radio_button_text is gui_button_text
style radio_vbox is pref_vbox

style check_label is pref_label
style check_label_text is pref_label_text
style check_button is gui_button
style check_button_text is gui_button_text
style check_vbox is pref_vbox

style slider_label is pref_label
style slider_label_text is pref_label_text
style slider_slider is gui_slider
style slider_button is gui_button
style slider_button_text is gui_button_text
style slider_pref_vbox is pref_vbox

style mute_all_button is check_button
style mute_all_button_text is check_button_text

style pref_label:
    top_margin gui.pref_spacing
    bottom_margin 3

style pref_label_text:
    yalign 1.0

style pref_vbox:
    xsize 338

style radio_vbox:
    spacing gui.pref_button_spacing

style radio_button:
    properties gui.button_properties("radio_button")
    foreground "gui/button/check_[prefix_]foreground.png"

style radio_button_text:
    properties gui.button_text_properties("radio_button")

style check_vbox:
    spacing gui.pref_button_spacing

style check_button:
    properties gui.button_properties("check_button")
    foreground "gui/button/check_[prefix_]foreground.png"

style check_button_text:
    properties gui.button_text_properties("check_button")

style slider_slider:
    xsize 525

style slider_button:
    properties gui.button_properties("slider_button")
    yalign 0.5
    left_margin 15

style slider_button_text:
    properties gui.button_text_properties("slider_button")

style slider_vbox:
    xsize 675


################################################################################
## Relationship screen ######################################################
################################################################################
screen relation_change():

    tag menu

    use game_menu(_("Change Relationships"), scroll="viewport"):

        if not main_menu and not renpy.variant("small"):
            hbox:

                vbox:
                    label _("Relationship Changer")

            hbox:
                text "{color=#888888}A te (játékbeli) neved: "
                button:
                    id "input_mct"
                    xminimum 200
                    yminimum 50
                    ymaximum 50
                    xmaximum 300
                    background "#000000"
                    hover_background "#5c5c5c"
                    yoffset -5
                    action NullAction()
                    add Input(default=persistent.mct, changed=mc_func, length=10, button=renpy.get_widget("text_input_screen","input_mct"))

            hbox:
                #xoffset 40
                #yoffset 40
                #add "bg/mia_intro_thumb.png" yoffset -5
                text "{color=#88888888}Jessica az én: "
                button:
                    id "input_j_rt"
                    xminimum 200
                    yminimum 50
                    ymaximum 50
                    xmaximum 300
                    background "#000000"
                    hover_background "#5c5c5c"
                    yoffset -5
                    action NullAction()
                    add Input(default=persistent.j_rt, changed=j_r_func, length=10, button=renpy.get_widget("text_input_screen","input_j_rt"))


            hbox:
                #xoffset 40
                #yoffset 60
                #add "bg/stara_intro_thumb.png" yoffset -5
                text "{color=#88888888}Megan az én: "
                button:
                    id "input_m_rt"
                    xminimum 200
                    yminimum 50
                    ymaximum 50
                    xmaximum 300
                    background "#000000"
                    hover_background "#5c5c5c"
                    yoffset -5
                    action NullAction()
                    add Input(default=persistent.m_rt, changed=m_r_func, length=10, button=renpy.get_widget("text_input_screen","input_m_rt"))

            hbox:
                #xoffset 40
                #yoffset 60
                #add "bg/stara_intro_thumb.png" yoffset -5
                text "{color=#88888888}Elizabeth az én: "
                button:
                    id "input_s_rt"
                    xminimum 200
                    yminimum 50
                    ymaximum 50
                    xmaximum 300
                    background "#000000"
                    hover_background "#5c5c5c"
                    yoffset -5
                    action NullAction()
                    add Input(default=persistent.s_rt, changed=s_r_func, length=10, button=renpy.get_widget("text_input_screen","input_s_rt"))

            hbox:
                #xoffset 40
                #yoffset 100
                #add "bg/mia_intro_thumb.png" yoffset -5
                text "{color=#888888}Én vagyok Jessica és Megan: "
                button:
                    id "input_b_rt"
                    xminimum 200
                    yminimum 50
                    ymaximum 50
                    xmaximum 300
                    background "#000000"
                    hover_background "#5c5c5c"
                    yoffset -5
                    action NullAction()
                    add Input(default=persistent.b_rt, changed=b_r_func, length=10, button=renpy.get_widget("text_input_screen","input_b_rt"))

            hbox:
                #xoffset 40
                #yoffset 120
                #add "bg/stara_intro_thumb.png" yoffset 30
                #add "bg/cale_intro_thumb.png" yoffset 30 xoffset 5
                text "{color=#888888}Én vagyok Elizabeth: " #xoffset 5
                button:
                    id "input_sont"
                    xminimum 200
                    yminimum 50
                    ymaximum 50
                    xmaximum 300
                    background "#000000"
                    hover_background "#5c5c5c"
                    yoffset -5
                    action NullAction()
                    add Input(default=persistent.sont, changed=son_func, length=10, button=renpy.get_widget("text_input_screen","input_sont"))

            hbox:
                #xoffset 150
                #yoffset 140
                text "{color=#888888}Jessica és Megan Elizabeth: "
                button:
                    id "input_d_rt"
                    xminimum 200
                    yminimum 50
                    ymaximum 50
                    xmaximum 300
                    background "#000000"
                    hover_background "#5c5c5c"
                    yoffset -5
                    action NullAction()
                    add Input(default=persistent.d_rt, changed=d_r_func, length=10, button=renpy.get_widget("text_input_screen","input_d_rt"))


################################################################################
## Voice Actresses screen ######################################################
################################################################################
screen vo_act():

    tag menu

    use game_menu(_("Voice Actresses"), scroll="viewport"):

        vbox:
            xpos 200
            ypos 100

            label _("{size=+20}{color=#f00}{b}VoiceLikeCandy{/b}{/color}{/size}")
            # textbutton _("Go to Website"):
            #     xoffset 125
            #     action OpenURL("http://www.patreon.com/voicelikecandy")

            textbutton _("Twitter"):
                xoffset 165
                action OpenURL("https://twitter.com/_VoiceLikeCandy")

            textbutton _("Listen to this!"):
                xoffset 128
                action Play("voice", "audio/vo/Profile_VoiceLikeCandy.ogg", selected=True)

        vbox:
            xpos 800
            yoffset -80

            label _("{size=+20}{color=#f00}{b}MissMoonified{/b}{/color}{/size}")
            # textbutton _("Go to Website"):
            #     xoffset 96
            #     action OpenURL("https://www.patreon.com/MissMoonified")

            textbutton _("Twitter"):
                xoffset 140
                action OpenURL("https://twitter.com/MissMoonified")

            textbutton _("Listen to this!"):
                xoffset 100
                action Play("voice", "audio/vo/Profile_MissMoonified.ogg", selected=True)

    on "show" action Stop("voice")
    on "hide" action Stop("voice")
    on "replace" action Stop("voice")
    on "replaced" action Stop("voice")


#style pref_label is gui_label
#style pref_label_text is gui_label_text
#style pref_vbox is vbox

#style radio_label is pref_label
#style radio_label_text is pref_label_text
#style radio_button is gui_button
#style radio_button_text is gui_button_text
#style radio_vbox is pref_vbox

#style check_label is pref_label
#style check_label_text is pref_label_text
#style check_button is gui_button
#style check_button_text is gui_button_text
#style check_vbox is pref_vbox

#style slider_label is pref_label
#style slider_label_text is pref_label_text
#style slider_slider is gui_slider
#style slider_button is gui_button
#style slider_button_text is gui_button_text
#style slider_pref_vbox is pref_vbox

#style mute_all_button is check_button
#style mute_all_button_text is check_button_text

#style pref_label:
#    top_margin gui.pref_spacing
#    bottom_margin 3

#style pref_label_text:
#    yalign 1.0

#style pref_vbox:
#    xsize 338

##style radio_vbox:
##    spacing gui.pref_button_spacing

#style radio_button:
#    properties gui.button_properties("radio_button")
#    foreground "gui/button/check_[prefix_]foreground.png"

#style radio_button_text:
#    properties gui.button_text_properties("radio_button")

##style check_vbox:
##    spacing gui.pref_button_spacing

#style check_button:
#    properties gui.button_properties("check_button")
#    foreground "gui/button/check_[prefix_]foreground.png"

#style check_button_text:
#    properties gui.button_text_properties("check_button")

#style slider_slider:
#    xsize 525

#style slider_button:
#    properties gui.button_properties("slider_button")
#    yalign 0.5
#    left_margin 15

#style slider_button_text:
#    properties gui.button_text_properties("slider_button")

#style slider_vbox:
#    xsize 675



## History screen ##############################################################
##
## This is a screen that displays the dialogue history to the player. While
## there isn't anything special about this screen, it does have to access the
## dialogue history stored in _history_list.
##
## https://www.renpy.org/doc/html/history.html

screen history():

    tag menu

    ## Avoid predicting this screen, as it can be very large.
    predict False

    use game_menu(_("History"), scroll=("vpgrid" if gui.history_height else "viewport"), yinitial=1.0):

        style_prefix "history"

        for h in _history_list:

            window:

                ## This lays things out properly if history_height is None.
                has fixed:
                    yfit True

                if h.who:

                    label h.who:
                        style "history_name"

                        ## Take the color of the who text from the Character, if
                        ## set.
                        if "color" in h.who_args:
                            text_color h.who_args["color"]

                $ what = renpy.filter_text_tags(h.what, allow=gui.history_allow_tags)
                text what

        if not _history_list:
            label _("The dialogue history is empty.")

## This determines what tags are allowed to be displayed on the history screen.

define gui.history_allow_tags = set()


style history_window is empty

style history_name is gui_label
style history_name_text is gui_label_text
style history_text is gui_text

style history_text is gui_text

style history_label is gui_label
style history_label_text is gui_label_text

style history_window:
    xfill True
    ysize gui.history_height

style history_name:
    xpos gui.history_name_xpos
    xanchor gui.history_name_xalign
    ypos gui.history_name_ypos
    xsize gui.history_name_width

style history_name_text:
    min_width gui.history_name_width
    text_align gui.history_name_xalign

style history_text:
    xpos gui.history_text_xpos
    ypos gui.history_text_ypos
    xanchor gui.history_text_xalign
    xsize gui.history_text_width
    min_width gui.history_text_width
    text_align gui.history_text_xalign
    layout ("subtitle" if gui.history_text_xalign else "tex")

style history_label:
    xfill True

style history_label_text:
    xalign 0.5


## Help screen #################################################################
##
## A screen that gives information about key and mouse bindings. It uses other
## screens (keyboard_help, mouse_help, and gamepad_help) to display the actual
## help.

screen help():

    tag menu

    if renpy.variant("pc"):
        default device = "keyboard"
    else:
        default device = "screen"

    use game_menu(_("Help"), scroll="viewport"):

        style_prefix "help"

        vbox:
            spacing 23

            vbox:
                if renpy.variant("pc"):
                    textbutton _("Keyboard") action SetScreenVariable("device", "keyboard")
                    textbutton _("Mouse") action SetScreenVariable("device", "mouse")
                if renpy.variant("touch"):
                    textbutton _("Screen") action SetScreenVariable("device", "screen")
                if GamepadExists():
                    textbutton _("Gamepad") action SetScreenVariable("device", "gamepad")

                side ("c r"):
                    area (1,0,1450,470)
                    viewport id "help":
                        draggable True mousewheel True

                        if device == "keyboard":
                            use keyboard_help
                        elif device == "mouse":
                            use mouse_help
                        elif device == "screen":
                            use screen_help
                        elif device == "gamepad":
                            use gamepad_help

                    vbar value YScrollValue("help")
            null height 20



screen keyboard_help():

    vbox:
        hbox:
            label _("Enter")
            text _("Továbbítja a párbeszédet és aktiválja az interfészt.")

        hbox:
            label _("Space")
            text _("Továbbítja a párbeszédet a választási lehetőségek kiválasztása nélkül.")

        hbox:
            label _("Arrow Keys")
            text _("Navigál a felületen.")

        hbox:
            label _("Escape")
            text _("Hozzáfér a játék menüjéhez.")

        hbox:
            label _("Ctrl")
            text _("A dialógus kihagyása, amíg lenyomva tartod.")

        hbox:
            label _("Tab")
            text _("A párbeszéd kihagyásának bekapcsolása.")

        hbox:
            label _("Page Up")
            text _("Visszalép a korábbi párbeszédhez.")

        hbox:
            label _("Page Down")
            text _("Előre a későbbi párbeszédhez.")

        hbox:
            label "H"
            text _("Elrejti a felhasználói felületet.")

        hbox:
            label "S"
            text _("Képernyőkép készítése.")

        hbox:
            label "V"
            text _("Bekapcsolja a segítő {a=https://www.renpy.org/l/voicing}önhangosítást{/a}.")

        hbox:
            label "P"
            text _("Pánikgomb")


screen mouse_help():

    vbox:
        hbox:
            label _("Left Click")
            text _("Előrehozza a párbeszédet és aktiválja a kezelőfelületet.")

        hbox:
            label _("Middle Click")
            text _("Elrejti a felhasználói felületet.")

        hbox:
            label _("Right Click")
            text _("Hozzáférés a játék menüjéhez.")

        hbox:
            label _("Mouse Wheel Up")
            text _("Visszalép a korábbi párbeszédhez.")

        hbox:
            label _("Mouse Wheel Down")
            text _("Előre a későbbi párbeszédhez.")


screen gamepad_help():

    vbox:
        hbox:
            label _("Right Trigger\nA/Bottom Button")
            text _("Továbblép a párbeszédhez és aktiválja a kezelőfelületet.")

        hbox:
            label _("Left Trigger\nLeft Shoulder")
            text _("Visszalép a korábbi párbeszédhez.")

        hbox:
            label _("Right Shoulder")
            text _("Továbblép a későbbi párbeszédhez.")


        hbox:
            label _("D-Pad, Sticks")
            text _("Navigál a felületen.")

        hbox:
            label _("Start, Guide")
            text _("Hozzáfér a játék menüjéhez.")

        hbox:
            label _("Y/Top Button")
            text _("Elrejti a felhasználói felületet.")

        textbutton _("Calibrate") action GamepadCalibrate()

screen screen_help():

    vbox:
        hbox:
            label _("Swipe Up & Down")
            text _("Elrejti a felhasználói felületet.")

        hbox:
            label _("Swipe Right")
            text _("Szöveg kihagyásának váltása.")

        hbox:
            label _("Swipe Left")
            text _("Visszaforgatás.")

        hbox:
            label _("Swipe Left & Right")
            text _("Megnyitja a játékmenüt.")



style help_button is gui_button
style help_button_text is gui_button_text
style help_label is gui_label
style help_label_text is gui_label_text
style help_text is gui_text

style help_button:
    properties gui.button_properties("help_button")
    xmargin 12

style help_button_text:
    properties gui.button_text_properties("help_button")

style help_label:
    xsize 375
    right_padding 30

style help_label_text:
    size gui.text_size
    xalign 1.0
    text_align 1.0



################################################################################
## Additional screens
################################################################################


## Confirm screen ##############################################################
##
## The confirm screen is called when Ren'Py wants to ask the player a yes or no
## question.
##
## https://www.renpy.org/doc/html/screen_special.html#confirm

screen confirm(message, yes_action, no_action):

    ## Ensure other screens do not get input while this screen is displayed.
    modal True

    zorder 200

    style_prefix "confirm"

    add "gui/overlay/confirm.png"

    frame:

        vbox:
            xalign .5
            yalign .5
            spacing 45

            label _(message):
                style "confirm_prompt"
                xalign 0.5

            hbox:
                xalign 0.5
                spacing 150

                textbutton _("Yes") action yes_action
                textbutton _("No") action no_action

    ## Right-click and escape answer "no".
    key "game_menu" action no_action


style confirm_frame is gui_frame
style confirm_prompt is gui_prompt
style confirm_prompt_text is gui_prompt_text
style confirm_button is gui_medium_button
style confirm_button_text is gui_medium_button_text

style confirm_frame:
    background Frame([ "gui/confirm_frame.png", "gui/frame.png"], gui.confirm_frame_borders, tile=gui.frame_tile)
    padding gui.confirm_frame_borders.padding
    xalign .5
    yalign .5

style confirm_prompt_text:
    text_align 0.5
    layout "subtitle"

style confirm_button:
    properties gui.button_properties("confirm_button")

style confirm_button_text:
    properties gui.button_text_properties("confirm_button")


## Skip indicator screen #######################################################
##
## The skip_indicator screen is displayed to indicate that skipping is in
## progress.
##
## https://www.renpy.org/doc/html/screen_special.html#skip-indicator

screen skip_indicator():

    zorder 100
    style_prefix "skip"

    frame:

        hbox:
            spacing 9

            text _("Kihagyás")

            text "▸" at delayed_blink(0.0, 1.0) style "skip_triangle"
            text "▸" at delayed_blink(0.2, 1.0) style "skip_triangle"
            text "▸" at delayed_blink(0.4, 1.0) style "skip_triangle"


## This transform is used to blink the arrows one after another.
transform delayed_blink(delay, cycle):
    alpha .5

    pause delay

    block:
        linear .2 alpha 1.0
        pause .2
        linear .2 alpha 0.5
        pause (cycle - .4)
        repeat


style skip_frame is empty
style skip_text is gui_text
style skip_triangle is skip_text

style skip_frame:
    ypos gui.skip_ypos
    background Frame("gui/skip.png", gui.skip_frame_borders, tile=gui.frame_tile)
    padding gui.skip_frame_borders.padding

style skip_text:
    size gui.notify_text_size

style skip_triangle:
    ## We have to use a font that has the BLACK RIGHT-POINTING SMALL TRIANGLE
    ## glyph in it.
    font "DejaVuSans.ttf"


## Notify screen ###############################################################
##
## The notify screen is used to show the player a message. (For example, when
## the game is quicksaved or a screenshot has been taken.)
##
## https://www.renpy.org/doc/html/screen_special.html#notify-screen

screen notify(message):

    zorder 100
    style_prefix "notify"

    frame at notify_appear:
        text "[message!tq]"

    timer 3.0 action Hide('notify')


transform notify_appear:
    on show:
        alpha 0
        linear .25 alpha 1.0
    on hide:
        linear .5 alpha 0.0


style notify_frame is empty
style notify_text is gui_text

style notify_frame:
    ypos gui.notify_ypos
    xalign 0.5

    background Frame("gui/notify.png", gui.notify_frame_borders, tile=gui.frame_tile)
    padding gui.notify_frame_borders.padding

style notify_text:
    properties gui.text_properties("notify")


## NVL screen ##################################################################
##
## This screen is used for NVL-mode dialogue and menus.
##
## https://www.renpy.org/doc/html/screen_special.html#nvl


screen nvl(dialogue, items=None):

    window:
        style "nvl_window"

        has vbox:
            spacing gui.nvl_spacing

        ## Displays dialogue in either a vpgrid or the vbox.
        if gui.nvl_height:

            vpgrid:
                cols 1
                yinitial 1.0

                use nvl_dialogue(dialogue)

        else:

            use nvl_dialogue(dialogue)

        ## Displays the menu, if given. The menu may be displayed incorrectly if
        ## config.narrator_menu is set to True, as it is above.
        for i in items:

            textbutton i.caption:
                action i.action
                style "nvl_button"

    add SideImage() xalign 0.0 yalign 1.0


screen nvl_dialogue(dialogue):

    for d in dialogue:

        window:
            id d.window_id

            fixed:
                yfit gui.nvl_height is None

                if d.who is not None:

                    text d.who:
                        id d.who_id

                text d.what:
                    id d.what_id


## This controls the maximum number of NVL-mode entries that can be displayed at
## once.
define config.nvl_list_length = gui.nvl_list_length

style nvl_window is default
style nvl_entry is default

style nvl_label is say_label
style nvl_dialogue is say_dialogue

style nvl_button is button
style nvl_button_text is button_text

style nvl_window:
    xfill True
    yfill True

    background "gui/nvl.png"
    padding gui.nvl_borders.padding

style nvl_entry:
    xfill True
    ysize gui.nvl_height

style nvl_label:
    xpos gui.nvl_name_xpos
    xanchor gui.nvl_name_xalign
    ypos gui.nvl_name_ypos
    yanchor 0.0
    xsize gui.nvl_name_width
    min_width gui.nvl_name_width
    text_align gui.nvl_name_xalign

style nvl_dialogue:
    xpos gui.nvl_text_xpos
    xanchor gui.nvl_text_xalign
    ypos gui.nvl_text_ypos
    xsize gui.nvl_text_width
    min_width gui.nvl_text_width
    text_align gui.nvl_text_xalign
    layout ("subtitle" if gui.nvl_text_xalign else "tex")

style nvl_thought:
    xpos gui.nvl_thought_xpos
    xanchor gui.nvl_thought_xalign
    ypos gui.nvl_thought_ypos
    xsize gui.nvl_thought_width
    min_width gui.nvl_thought_width
    text_align gui.nvl_thought_xalign
    layout ("subtitle" if gui.nvl_text_xalign else "tex")

style nvl_button:
    properties gui.button_properties("nvl_button")
    xpos gui.nvl_button_xpos
    xanchor gui.nvl_button_xalign

style nvl_button_text:
    properties gui.button_text_properties("nvl_button")



################################################################################
## Mobile Variants
################################################################################

style pref_vbox:
    variant "medium"
    xsize 675

## Since a mouse may not be present, we replace the quick menu with a version
## that uses fewer and bigger buttons that are easier to touch.
#screen quick_menu():
    #variant "touch"

    #zorder 100

    #hbox:
        #style_prefix "quick"

        #xalign 0.5
        #yalign 1.0

        #textbutton _("Back") action Rollback()
        #textbutton _("Skip") action Skip() alternate Skip(fast=True, confirm=True)
        #textbutton _("Auto") action Preference("auto-forward", "toggle")
        #textbutton _("Menu") action ShowMenu()

style window:
    variant "small"
    background "gui/phone/textbox.png"

style radio_button:
    variant "small"
    foreground "gui/phone/button/check_[prefix_]foreground.png"

style check_button:
    variant "small"
    foreground "gui/phone/button/check_[prefix_]foreground.png"

style nvl_window:
    variant "small"
    background "gui/phone/nvl.png"

style main_menu_frame:
    variant "small"
    background "gui/phone/overlay/main_menu.png"

style game_menu_outer_frame:
    variant "small"
    background "gui/phone/overlay/game_menu.png"

style game_menu_navigation_frame:
    variant "small"
    xsize 510

style game_menu_content_frame:
    variant "small"
    top_margin 0

style pref_vbox:
    variant "small"
    xsize 600

style bar:
    variant "small"
    ysize gui.bar_size
    left_bar Frame("gui/phone/bar/left.png", gui.bar_borders, tile=gui.bar_tile)
    right_bar Frame("gui/phone/bar/right.png", gui.bar_borders, tile=gui.bar_tile)

style vbar:
    variant "small"
    xsize gui.bar_size
    top_bar Frame("gui/phone/bar/top.png", gui.vbar_borders, tile=gui.bar_tile)
    bottom_bar Frame("gui/phone/bar/bottom.png", gui.vbar_borders, tile=gui.bar_tile)

style scrollbar:
    variant "small"
    ysize gui.scrollbar_size
    base_bar Frame("gui/phone/scrollbar/horizontal_[prefix_]bar.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/phone/scrollbar/horizontal_[prefix_]thumb.png", gui.scrollbar_borders, tile=gui.scrollbar_tile)

style vscrollbar:
    variant "small"
    xsize gui.scrollbar_size
    base_bar Frame("gui/phone/scrollbar/vertical_[prefix_]bar.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)
    thumb Frame("gui/phone/scrollbar/vertical_[prefix_]thumb.png", gui.vscrollbar_borders, tile=gui.scrollbar_tile)

style slider:
    variant "small"
    ysize gui.slider_size
    base_bar Frame("gui/phone/slider/horizontal_[prefix_]bar.png", gui.slider_borders, tile=gui.slider_tile)
    thumb "gui/phone/slider/horizontal_[prefix_]thumb.png"

style vslider:
    variant "small"
    xsize gui.slider_size
    base_bar Frame("gui/phone/slider/vertical_[prefix_]bar.png", gui.vslider_borders, tile=gui.slider_tile)
    thumb "gui/phone/slider/vertical_[prefix_]thumb.png"

style slider_pref_vbox:
    variant "small"
    xsize None

style slider_pref_slider:
    variant "small"
    xsize 900
